@@ -6,20 +6,12 @@ alignpatch.alignpatches <- function(x) {
 
 #' @noRd
 PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
-    # We by default won't collect any guides
-    guides = NULL,
-    theme = NULL,
-    set_guides = function(self, guides, plot = self$plot) guides,
-    set_theme = function(self, theme, plot = self$plot) {
-        if (is.null(t <- .subset2(plot, "theme"))) return(theme) # styler: off
-        # we'll always initialize the parent layout theme
-        # so it won't be NULL
-        theme + t
-    },
+    set_guides = function(self, guides) guides,
     #' @importFrom gtable gtable gtable_add_grob
     #' @importFrom grid unit
-    #' @importFrom ggplot2 wrap_dims calc_element zeroGrob
-    patch_gtable = function(self, top_level = FALSE, plot = self$plot) {
+    #' @importFrom ggplot2 wrap_dims calc_element zeroGrob theme_get
+    patch_gtable = function(self, theme = theme_get(), guides = NULL,
+                            top_level = FALSE, plot = self$plot) {
         patches <- lapply(.subset2(plot, "plots"), alignpatch)
         layout <- .subset2(plot, "layout")
 
@@ -62,6 +54,7 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
 
         # if no plots, we return empty gtable -----------------
         if (is_empty(patches)) return(make_patch_table()) # styler: off
+        self$patches <- patches
 
         # add borders to patch --------------------------------
         design <- vec_slice(design, keep)
@@ -84,26 +77,17 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
 
         # we inherit parameters from the parent --------------------
         # by default, we won't collect any guide legends
-        guides <- .subset2(layout, "guides") %|w|% self$guides
+        parent_guides <- guides
+        guides <- .subset2(layout, "guides") %|w|% parent_guides
 
         # by default, we use ggplot2 default theme
-        theme <- self$theme %||% self$set_theme(theme_get(), plot = plot)
-
-        # Let each patch to determine whether to collect guides or inherit
-        # the theme
-        for (patch in patches) {
-            patch$guides <- patch$set_guides(guides)
-            patch$theme <- patch$set_theme(theme)
-        }
-
-        # save patches, patches isnot copyable -------------------
-        self$patches <- patches
+        if (!is.null(plot$theme)) theme <- theme + plot$theme
+        self$theme <- theme
 
         #######################################################
         # 1. patch_gtable: create the gtable for the patch, will set internal
         #    `gt`
-        # 2. collect_guides_list: call `collect_guides`, can change the internal
-        #    `gt`
+        # 2. `collect_guides`, can change the internal `gt`
         # 3. set_sizes:
         #     - (To-Do) align_panel_spaces: can change the internal `gt`
         #     - align_panel_sizes, can change the internal `gt`
@@ -111,12 +95,27 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
         # 4. set_grobs: will call `align_border` and `split_gt`, return the
         #    final gtable
         # setup gtable list ----------------------------------
-        for (patch in patches) {
-            patch$gt <- patch$patch_gtable()
+        # Let each patch to determine whether to collect guides
+        collected <- lapply(patches, function(patch) patch$set_guides(guides))
+        collected_guides <- vector("list", length(patches))
+
+        # Always ensure that plots placed in a border collect their guides, if
+        # any guides are to be collected in that border. This prevents overlap,
+        # unless the guides will be collected by the parent layout.
+        border_with_guides <- unique(unlist(collected, FALSE, FALSE))
+        border_with_guides <- setdiff(border_with_guides, parent_guides)
+        for (i in seq_along(patches)) {
+            patch <- .subset2(patches, i)
+            g <- union(
+                .subset2(collected, i),
+                intersect(border_with_guides, patch$borders)
+            )
+            patch$gt <- patch$patch_gtable(theme = theme, guides = g)
+            collected_guides[i] <- list(patch$collect_guides(g))
         }
 
         # collect guides  ---------------------------------------
-        collected_guides <- self$collect_guides_list(patches)
+        self$collected_guides <- collect_guides_list(collected_guides)
 
         # prepare the output ----------------------------------
         gt <- gtable(
@@ -141,15 +140,11 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
         # add guides into the final gtable ----------------------
         if (top_level) {
             gt <- self$attach_guide_list(
-                guide_list = collected_guides,
+                guide_list = self$collected_guides,
                 theme = theme,
                 panel_pos = panel_pos,
                 gt = gt
             )
-        } else {
-            # used by `$collect_guides() method`
-            self$collected_guides <- collected_guides
-            self$panel_pos <- panel_pos
         }
 
         # setup grobs -------------------------------------------
@@ -210,7 +205,7 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
             patch$align_border(t = t, l = l, b = b, r = r, gt = grob)
         }, t = t, l = l, b = b, r = r, gt = gt, patches = patches)
     },
-    collect_guides = function(self, guides = self$guides, gt = self$gt) {
+    collect_guides = function(self, guides, gt = self$gt) {
         collected_guides <- self$collected_guides
         # for guides not collected by the top-level alignpatches, we attach the
         # guides
@@ -223,36 +218,6 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
         # return guides to be collected
         .subset(collected_guides, guides)
     },
-    collect_guides_list = function(self, patches) {
-        guides_list <- lapply(patches, function(patch) patch$collect_guides())
-        ans <- lapply(c(.TLBR, "inside"), function(guide_pos) {
-            guides <- lapply(guides_list, function(guides) {
-                o <- .subset2(guides, guide_pos)
-                # A guide-box should be a `zeroGrob()` or a `gtable` object
-                if (maybe_guide_box(o)) {
-                    return(list(o))
-                }
-                # For other grobs, we just removed them silently
-                if (is.grob(o)) {
-                    list(NULL)
-                } else if (is.list(o)) {
-                    o[vapply(o, maybe_guide_box,
-                        logical(1L),
-                        USE.NAMES = FALSE
-                    )]
-                } else {
-                    list(NULL)
-                }
-            })
-            guides <- unlist(guides, FALSE, FALSE)
-            guides <- guides[
-                !vapply(guides, is.null, logical(1L), USE.NAMES = FALSE)
-            ]
-            if (is_empty(guides)) NULL else guides
-        })
-        names(ans) <- c(.TLBR, "inside")
-        ans[!vapply(ans, is.null, logical(1L), USE.NAMES = FALSE)]
-    },
     #' @importFrom grid is.unit unit
     set_sizes = function(self, design, dims,
                          panel_widths, panel_heights,
@@ -403,7 +368,7 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
         gt
     },
     attach_guide_list = function(self, guide_list, theme = self$theme,
-                                 panel_pos = self$panel_pos,
+                                 panel_pos = find_panel(gt),
                                  gt = self$gt) {
         if (length(guide_list)) {
             # https://github.com/tidyverse/ggplot2/blob/57ba97fa04dadc6fd73db1904e39a09d57a4fcbe/R/guides-.R#L512
@@ -430,81 +395,22 @@ PatchAlignpatches <- ggproto("PatchAlignpatches", Patch,
     attach_guides = function(self, guide_pos, guides, theme,
                              panel_pos = find_panel(gt), ...,
                              gt = self$gt) {
-        # for inside legends, they'll be grouped by the actual inside
-        # position and justification
+        guide_box <- assemble_guides(guides, guide_pos, theme = theme)
+        name <- sprintf("guide-box-collected-%s", guide_pos)
         if (guide_pos == "inside") {
-            name <- sprintf("guide-box-collected-%s", guide_pos)
-            # for `zeroGrob()`, it doesn't record the `viewport` information
-            # used to identify the inside guide groups, we just removed them
-            guides <- guides[!vapply(guides, is_null_grob,
-                logical(1L),
-                USE.NAMES = FALSE
-            )]
-            if (is_empty(guides)) {
-                index <- 1L
-            } else {
-                positions <- justs <- vector("list", length(guides))
-                for (i in seq_along(guides)) {
-                    guide <- .subset2(guides, i)
-                    # for inside guides, it may contain multiple guide-box
-                    is_box <- grepl("guide-box-inside", guide$layout$name)
-                    if (any(is_box)) {
-                        guides[[i]] <- guide$grobs[is_box]
-                    } else {
-                        guides[[i]] <- list(guide)
-                    }
-                    positions[[i]] <- lapply(guides[[i]], function(guide_box) {
-                        unit.c(guide_box$vp$x, guide_box$vp$y)
-                    })
-                    justs[[i]] <- lapply(guides[[i]], function(guide_box) {
-                        guide_box$vp$justification
-                    })
-                }
-                guides <- unlist(guides, FALSE, FALSE)
-                groups <- data_frame0(
-                    positions = unlist(positions, FALSE, FALSE),
-                    justs = unlist(justs, FALSE, FALSE)
-                )
-                groups <- vec_group_loc(groups)
-                index <- vec_seq_along(groups)
-                if (vec_size(groups) > 1L) {
-                    name <- paste(name, index, sep = "-")
-                }
-            }
-
-            # pakcage each group into a guide-box and add it into the `gt`
-            for (i in index) {
-                if (is_empty(guides)) {
-                    guide_box <- zeroGrob()
-                } else {
-                    adjust <- theme(
-                        legend.position.inside = groups$key$positions[[i]],
-                        legend.justification.inside = groups$key$justs[[i]]
-                    )
-                    guide_box <- assemble_guides(
-                        guides[groups$loc[[i]]], guide_pos,
-                        theme = theme + adjust
-                    )
-                }
-                gt <- gtable_add_grob(
-                    x = gt,
-                    grobs = guide_box,
-                    t = panel_pos$t,
-                    l = panel_pos$l,
-                    b = panel_pos$b,
-                    r = panel_pos$r,
-                    name = name[[i]],
-                    ...
-                )
-            }
+            gt <- gtable_add_grob(
+                x = gt,
+                grobs = guide_box,
+                t = panel_pos$t,
+                l = panel_pos$l,
+                b = panel_pos$b,
+                r = panel_pos$r,
+                name = name,
+                ...
+            )
             return(gt)
         }
-
-        guide_box <- assemble_guides(guides, guide_pos, theme = theme)
-
-        # global parameters
         spacing <- .subset2(theme, "legend.box.spacing")
-        name <- sprintf("guide-box-collected-%s", guide_pos)
         if (guide_pos == "left") {
             if (is.gtable(guide_box)) {
                 legend_width <- gtable_width(guide_box)
