@@ -54,7 +54,7 @@ alignpatch.free_lab <- function(x) {
     ggproto(
         "PatchFreeLab", Parent,
         free_labs = setup_pos(attr(x, "free_labs")),
-        collect_guides = function(self, guides = self$guides, gt = self$gt) {
+        collect_guides = function(self, guides, gt = self$gt) {
             ans <- ggproto_parent(Parent, self)$collect_guides(
                 guides = guides, gt = gt
             )
