@@ -8,12 +8,12 @@ rasterise.QuadLayout <- function(input, ...) {
     input
 }
 
-rasterise.StackLayout <- function(input, ...) {
+rasterise.ChainLayout <- function(input, ...) {
     input@plot_list <- lapply(input@plot_list, ggrastr::rasterise, ...)
     input
 }
 
-rasterise.ggalign_plot <- function(input, ...) {
+rasterise.CraftBox <- function(input, ...) {
     if (!is.null(plot <- input@plot)) {
         input@plot <- ggrastr::rasterise(input = plot, ...)
     }
@@ -22,27 +22,27 @@ rasterise.ggalign_plot <- function(input, ...) {
 
 ##########################################################
 #' @export
-.raster_magick.QuadLayout <- function(x, magick = NULL, ...) {
-    x@plot <- .raster_magick(x = x@plot, ...)
+raster_magick0.QuadLayout <- function(x, ...) {
+    x@plot <- raster_magick0(x = x@plot, ...)
     for (position in .TLBR) {
         stack <- slot(x, position)
         if (is.null(stack)) next
-        slot(x, position) <- .raster_magick(x = stack, magick = magick, ...)
+        slot(x, position) <- raster_magick0(x = stack, ...)
     }
     x
 }
 
 #' @export
-.raster_magick.StackLayout <- function(x, magick = NULL, ...) {
-    x@plot_list <- lapply(x@plot_list, .raster_magick, magick = magick, ...)
+raster_magick0.ChainLayout <- function(x, ...) {
+    x@plot_list <- lapply(x@plot_list, raster_magick0, ...)
     x
 }
 
 
 #' @export
-.raster_magick.ggalign_plot <- function(x, magick = NULL, ...) {
+raster_magick0.CraftBox <- function(x, ...) {
     if (!is.null(plot <- input@plot)) {
-        input@plot <- .raster_magick(x = plot, ...)
+        input@plot <- raster_magick0(x = plot, ...)
     }
     input
 }
