@@ -1,12 +1,11 @@
 # `assert_*()` functions will do the side effects
 # `check_*()` functions will return the arguments
-#' @importFrom rlang caller_arg caller_env
-assert_gp <- function(gp, arg = caller_arg(gp),
-                      call = caller_env()) {
+#' @importFrom rlang caller_arg caller_call
+assert_gp <- function(gp, arg = caller_arg(gp), call = caller_call()) {
     assert_s3_class(gp, "gpar", arg = arg, call = call)
 }
 
-#' @importFrom rlang caller_arg caller_env
+#' @importFrom rlang caller_arg caller_call
 assert_mapping <- function(mapping, arg = caller_arg(mapping),
                            call = caller_call()) {
     if (!inherits(mapping, "uneval")) {
@@ -100,7 +99,7 @@ check_stack_sizes <- function(sizes, arg = caller_arg(sizes),
     l <- length(sizes)
     if (l != 1L && l != 3L) {
         cli_abort(
-            "{.arg {arg}} must have size 1 or 3, not size {l}",
+            "{.arg {arg}} must have size `1` or `3`, not size {l}",
             call = call
         )
     }
@@ -114,10 +113,7 @@ check_direction <- function(direction, arg = caller_arg(direction),
     direction <- arg_match0(direction, c("h", "v"),
         arg_nm = arg, error_call = call
     )
-    switch(direction,
-        h = "horizontal",
-        v = "vertical"
-    )
+    switch(direction, h = "horizontal", v = "vertical") # styler: off
 }
 
 assert_limits <- function(limits, allow_null = TRUE, arg = caller_arg(limits),
@@ -141,8 +137,8 @@ assert_limits <- function(limits, allow_null = TRUE, arg = caller_arg(limits),
 
 #' @importFrom grid is.unit
 check_size <- function(size, arg = caller_arg(size), call = caller_call()) {
-    vec_check_size(size, size = 1L, arg = arg, call = call)
-    if (!(is.na(size) || is.numeric(size) || is.unit(size))) {
+    if (!is_scalar(size) &&
+        !(is.na(size) || is.numeric(size) || is.unit(size))) {
         cli_abort(
             "{.arg {arg}} must be a single numeric or unit object",
             call = call
@@ -154,8 +150,8 @@ check_size <- function(size, arg = caller_arg(size), call = caller_call()) {
 
 check_scheme_data <- function(data, arg = caller_arg(data),
                               call = caller_call()) {
-    data <- allow_lambda(data)
-    if (!is.waive(data) && !is.null(data) && !is.function(data)) {
+    if (!is.waive(data) && !is.null(data) &&
+        !is.function(data <- allow_lambda(data))) {
         cli_abort(paste(
             "{.arg {arg}} must be a function,",
             "{.code NULL} or {.fn waiver}"
@@ -167,61 +163,30 @@ check_scheme_data <- function(data, arg = caller_arg(data),
 check_stack_context <- function(what, arg = caller_arg(what),
                                 call = caller_call()) {
     if (is.null(what)) return(what) # styler: off
-    if (!is_scalar(what) || !(is.numeric(what) || is.character(what))) {
-        cli_abort("{.arg {arg}} must be a single number or string",
+    if (.rlang_check_number(what, allow_decimal = FALSE, min = 1) != 0L &&
+        !is_string(what)) {
+        cli_abort(
+            "{.arg {arg}} must be a single positive integer number or string",
             call = call
         )
-    } else if (anyNA(what)) {
-        cli_abort("{.arg {arg}} cannot be {.code NA}", call = call)
-    } else if (is.numeric(what)) {
-        what <- vec_cast(what, integer(), x_arg = arg, call = call)
-        if (what <= 0L) {
-            cli_abort(
-                "{.arg {arg}} must be a positive integer",
-                call = call
-            )
-        }
     }
     what
 }
 
 check_order <- function(order, arg = caller_arg(order), call = caller_call()) {
     if (is.null(order)) {
-        order <- NA_integer_
-    } else if (!is_scalar(order) || (!is.numeric(order) && !is.na(order))) {
-        cli_abort("{.arg {arg}} must be a single number", call = call)
+        NA_integer_
+    } else if (.rlang_check_number(order, allow_decimal = FALSE) == 0L) {
+        as.integer(order)
     } else {
-        order <- vec_cast(order, integer(), x_arg = arg, call = call)
-    }
-    order
-}
-
-#' @importFrom ggplot2 Facet
-assert_facet <- function(x, arg = caller_arg(x), call = caller_call()) {
-    # Check if we can overide core functions of Facet
-    valid_init <- identical(
-        body(environment(Facet$init_scales)$f),
-        body(environment(x$init_scales)$f)
-    )
-    valid_train <- identical(
-        body(environment(Facet$train_scales)$f),
-        body(environment(x$train_scales)$f)
-    )
-    valid_finish <- identical(
-        body(environment(Facet$finish_data)$f),
-        body(environment(x$finish_data)$f)
-    )
-    if (!all(c(valid_init, valid_train, valid_finish))) {
-        cli_warn(c(
-            "Unknown facet: {.obj_type_friendly {x}}.",
-            i = "Overriding facetted scales may be unstable."
-        ))
+        cli_abort("{.arg {arg}} must be single integer number", call = call)
     }
 }
 
 assert_align <- function(x, arg = caller_arg(x), call = caller_call()) {
     if (!inherits(x, "scheme_align")) {
-        cli_abort("{.arg {arg}} must be created by {.fn scheme_align}",
+        cli_abort(
+            "{.arg {arg}} must be created by {.fn scheme_align}",
             call = call
         )
     }
@@ -233,7 +198,8 @@ assert_active <- function(x, allow_null = TRUE,
         return(invisible(NULL))
     }
     if (!inherits(x, "ggalign_active")) {
-        cli_abort("{.arg {arg}} must be created by {.fn active}",
+        cli_abort(
+            "{.arg {arg}} must be created by {.fn active}",
             call = call
         )
     }
@@ -241,17 +207,10 @@ assert_active <- function(x, allow_null = TRUE,
 
 assert_obs_size <- function(obs_size, arg = caller_arg(obs_size),
                             call = caller_call()) {
-    if (.standalone_types_check_assert_call(
-        ffi_standalone_check_number_1.0.7,
-        obs_size,
-        allow_decimal = TRUE,
-        .Machine$double.eps,
-        1,
-        FALSE,
-        FALSE,
-        FALSE
-    ) != 0L) {
-        cli_abort("{.arg {arg}} must be a single number in `(0, 1]`",
+    if (.rlang_check_number(obs_size, allow_decimal = TRUE,  # styler: off
+                            .Machine$double.eps, 1) != 0L) { # styler: off
+        cli_abort(
+            "{.arg {arg}} must be a single number in `(0, 1]`",
             call = call
         )
     }
