@@ -3,8 +3,8 @@
     theme_elements()
 
     # register method for
-    s3_register("ggrastr::rasterise", "ggalign_plot")
+    s3_register("ggrastr::rasterise", "CraftBox")
     s3_register("ggrastr::rasterise", "QuadLayout")
-    s3_register("ggrastr::rasterise", "StackLayout")
+    s3_register("ggrastr::rasterise", "ChainLayout")
     invisible()
 }
