@@ -4,12 +4,12 @@
 #   - CI is not set (on CRAN)
 
 expect_doppelganger <- tryCatch(
-    getExportedValue("vdiffr", "expect_doppelganger"),
+    vdiffr::expect_doppelganger,
     error = function(cnd) {
         # If vdiffr is not available and visual tests are not explicitly
         # disabled, raise error.
         if (!identical(Sys.getenv("VDIFFR_RUN_TESTS"), "false")) {
-            cli::cli_abort("{.pkg vdiffr} is not installed")
+            cli_abort("{.pkg vdiffr} is not installed")
         }
 
         # Otherwise, assign a dummy function
